@@ -22,9 +22,10 @@
 #ifndef HEXFILE_H
 #define HEXFILE_H 1
 
+unsigned int
+Ascii2Hex(char *istring, int length);
 
 void
 LoadHexFile( const char *filename );
 
-
 #endif /* HEXFILE_H */
